==> chaosmesh-model-5.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/IoChaosActionFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface IoChaosActionFluent<A extends IoChaosActionFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAtime instead.
 * @return The buildable object.
 */
@Deprecated public Timespec getAtime();
    public Timespec buildAtime();
    public A withAtime(Timespec atime);
    public Boolean hasAtime();
    public A withNewAtime(Long nsec,Long sec);
    public IoChaosActionFluent.AtimeNested<A> withNewAtime();
    public IoChaosActionFluent.AtimeNested<A> withNewAtimeLike(Timespec item);
    public IoChaosActionFluent.AtimeNested<A> editAtime();
    public IoChaosActionFluent.AtimeNested<A> editOrNewAtime();
    public IoChaosActionFluent.AtimeNested<A> editOrNewAtimeLike(Timespec item);
    public Long getBlocks();
    public A withBlocks(Long blocks);
    public Boolean hasBlocks();
    public A withNewBlocks(long arg1);
    
/**
 * This method has been deprecated, please use method buildCtime instead.
 * @return The buildable object.
 */
@Deprecated public Timespec getCtime();
    public Timespec buildCtime();
    public A withCtime(Timespec ctime);
    public Boolean hasCtime();
    public A withNewCtime(Long nsec,Long sec);
    public IoChaosActionFluent.CtimeNested<A> withNewCtime();
    public IoChaosActionFluent.CtimeNested<A> withNewCtimeLike(Timespec item);
    public IoChaosActionFluent.CtimeNested<A> editCtime();
    public IoChaosActionFluent.CtimeNested<A> editOrNewCtime();
    public IoChaosActionFluent.CtimeNested<A> editOrNewCtimeLike(Timespec item);
    public A addToFaults(int index,IoFault item);
    public A setToFaults(int index,IoFault item);
    public A addToFaults(IoFault... items);
    public A addAllToFaults(Collection<IoFault> items);
    public A removeFromFaults(IoFault... items);
    public A removeAllFromFaults(Collection<IoFault> items);
    public A removeMatchingFromFaults(Predicate<IoFaultBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildFaults instead.
 * @return The buildable object.
 */
@Deprecated public List<IoFault> getFaults();
    public List<IoFault> buildFaults();
    public IoFault buildFault(int index);
    public IoFault buildFirstFault();
    public IoFault buildLastFault();
    public IoFault buildMatchingFault(Predicate<IoFaultBuilder> predicate);
    public Boolean hasMatchingFault(Predicate<IoFaultBuilder> predicate);
    public A withFaults(List<IoFault> faults);
    public A withFaults(IoFault... faults);
    public Boolean hasFaults();
    public A addNewFault(Integer errno,Integer weight);
    public IoChaosActionFluent.FaultsNested<A> addNewFault();
    public IoChaosActionFluent.FaultsNested<A> addNewFaultLike(IoFault item);
    public IoChaosActionFluent.FaultsNested<A> setNewFaultLike(int index,IoFault item);
    public IoChaosActionFluent.FaultsNested<A> editFault(int index);
    public IoChaosActionFluent.FaultsNested<A> editFirstFault();
    public IoChaosActionFluent.FaultsNested<A> editLastFault();
    public IoChaosActionFluent.FaultsNested<A> editMatchingFault(Predicate<IoFaultBuilder> predicate);
    public Long getGid();
    public A withGid(Long gid);
    public Boolean hasGid();
    public A withNewGid(long arg1);
    public Long getIno();
    public A withIno(Long ino);
    public Boolean hasIno();
    public A withNewIno(long arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public String getLatency();
    public A withLatency(String latency);
    public Boolean hasLatency();
    public A withNewLatency(StringBuilder arg1);
    public A withNewLatency(int[] arg1,int arg2,int arg3);
    public A withNewLatency(char[] arg1);
    public A withNewLatency(StringBuffer arg1);
    public A withNewLatency(byte[] arg1,int arg2);
    public A withNewLatency(byte[] arg1);
    public A withNewLatency(char[] arg1,int arg2,int arg3);
    public A withNewLatency(byte[] arg1,int arg2,int arg3);
    public A withNewLatency(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewLatency(String arg1);
    public A addToMethods(int index,String item);
    public A setToMethods(int index,String item);
    public A addToMethods(String... items);
    public A addAllToMethods(Collection<String> items);
    public A removeFromMethods(String... items);
    public A removeAllFromMethods(Collection<String> items);
    public List<String> getMethods();
    public String getMethod(int index);
    public String getFirstMethod();
    public String getLastMethod();
    public String getMatchingMethod(Predicate<String> predicate);
    public Boolean hasMatchingMethod(Predicate<String> predicate);
    public A withMethods(List<String> methods);
    public A withMethods(String... methods);
    public Boolean hasMethods();
    public A addNewMethod(StringBuilder arg1);
    public A addNewMethod(int[] arg1,int arg2,int arg3);
    public A addNewMethod(char[] arg1);
    public A addNewMethod(StringBuffer arg1);
    public A addNewMethod(byte[] arg1,int arg2);
    public A addNewMethod(byte[] arg1);
    public A addNewMethod(char[] arg1,int arg2,int arg3);
    public A addNewMethod(byte[] arg1,int arg2,int arg3);
    public A addNewMethod(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewMethod(String arg1);
    
/**
 * This method has been deprecated, please use method buildMtime instead.
 * @return The buildable object.
 */
@Deprecated public Timespec getMtime();
    public Timespec buildMtime();
    public A withMtime(Timespec mtime);
    public Boolean hasMtime();
    public A withNewMtime(Long nsec,Long sec);
    public IoChaosActionFluent.MtimeNested<A> withNewMtime();
    public IoChaosActionFluent.MtimeNested<A> withNewMtimeLike(Timespec item);
    public IoChaosActionFluent.MtimeNested<A> editMtime();
    public IoChaosActionFluent.MtimeNested<A> editOrNewMtime();
    public IoChaosActionFluent.MtimeNested<A> editOrNewMtimeLike(Timespec item);
    public Long getNlink();
    public A withNlink(Long nlink);
    public Boolean hasNlink();
    public A withNewNlink(long arg1);
    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(int[] arg1,int arg2,int arg3);
    public A withNewPath(char[] arg1);
    public A withNewPath(StringBuffer arg1);
    public A withNewPath(byte[] arg1,int arg2);
    public A withNewPath(byte[] arg1);
    public A withNewPath(char[] arg1,int arg2,int arg3);
    public A withNewPath(byte[] arg1,int arg2,int arg3);
    public A withNewPath(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPath(String arg1);
    public Integer getPercent();
    public A withPercent(Integer percent);
    public Boolean hasPercent();
    public A withNewPercent(int arg1);
    public Integer getPerm();
    public A withPerm(Integer perm);
    public Boolean hasPerm();
    public A withNewPerm(int arg1);
    public Long getRdev();
    public A withRdev(Long rdev);
    public Boolean hasRdev();
    public A withNewRdev(long arg1);
    public Long getSize();
    public A withSize(Long size);
    public Boolean hasSize();
    public A withNewSize(long arg1);
    public String getSource();
    public A withSource(String source);
    public Boolean hasSource();
    public A withNewSource(StringBuilder arg1);
    public A withNewSource(int[] arg1,int arg2,int arg3);
    public A withNewSource(char[] arg1);
    public A withNewSource(StringBuffer arg1);
    public A withNewSource(byte[] arg1,int arg2);
    public A withNewSource(byte[] arg1);
    public A withNewSource(char[] arg1,int arg2,int arg3);
    public A withNewSource(byte[] arg1,int arg2,int arg3);
    public A withNewSource(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSource(String arg1);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(StringBuilder arg1);
    public A withNewType(int[] arg1,int arg2,int arg3);
    public A withNewType(char[] arg1);
    public A withNewType(StringBuffer arg1);
    public A withNewType(byte[] arg1,int arg2);
    public A withNewType(byte[] arg1);
    public A withNewType(char[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewType(String arg1);
    public Long getUid();
    public A withUid(Long uid);
    public Boolean hasUid();
    public A withNewUid(long arg1);
    public interface AtimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TimespecFluent<IoChaosActionFluent.AtimeNested<N>> {

            public N and();
            public N endAtime();    }


    public interface CtimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TimespecFluent<IoChaosActionFluent.CtimeNested<N>> {

            public N and();
            public N endCtime();    }


    public interface FaultsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IoFaultFluent<IoChaosActionFluent.FaultsNested<N>> {

            public N and();
            public N endFault();    }


    public interface MtimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TimespecFluent<IoChaosActionFluent.MtimeNested<N>> {

            public N and();
            public N endMtime();    }


}

==> chaosmesh-model-5.3.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/IoChaosActionFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface IoChaosActionFluent<A extends IoChaosActionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAtime instead.
 * @return The buildable object.
 */
@Deprecated public Timespec getAtime();
    public Timespec buildAtime();
    public A withAtime(Timespec atime);
    public Boolean hasAtime();
    public A withNewAtime(Long nsec,Long sec);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.AtimeNested<A> withNewAtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.AtimeNested<A> withNewAtimeLike(Timespec item);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.AtimeNested<A> editAtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.AtimeNested<A> editOrNewAtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.AtimeNested<A> editOrNewAtimeLike(Timespec item);
    public Long getBlocks();
    public A withBlocks(Long blocks);
    public Boolean hasBlocks();
    public A withNewBlocks(long arg1);
    
/**
 * This method has been deprecated, please use method buildCtime instead.
 * @return The buildable object.
 */
@Deprecated public Timespec getCtime();
    public Timespec buildCtime();
    public A withCtime(Timespec ctime);
    public Boolean hasCtime();
    public A withNewCtime(Long nsec,Long sec);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.CtimeNested<A> withNewCtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.CtimeNested<A> withNewCtimeLike(Timespec item);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.CtimeNested<A> editCtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.CtimeNested<A> editOrNewCtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.CtimeNested<A> editOrNewCtimeLike(Timespec item);
    public A addToFaults(int index,IoFault item);
    public A setToFaults(int index,IoFault item);
    public A addToFaults(IoFault... items);
    public A addAllToFaults(Collection<IoFault> items);
    public A removeFromFaults(IoFault... items);
    public A removeAllFromFaults(Collection<IoFault> items);
    public A removeMatchingFromFaults(Predicate<IoFaultBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildFaults instead.
 * @return The buildable object.
 */
@Deprecated public List<IoFault> getFaults();
    public List<IoFault> buildFaults();
    public IoFault buildFault(int index);
    public IoFault buildFirstFault();
    public IoFault buildLastFault();
    public IoFault buildMatchingFault(Predicate<IoFaultBuilder> predicate);
    public Boolean hasMatchingFault(Predicate<IoFaultBuilder> predicate);
    public A withFaults(List<IoFault> faults);
    public A withFaults(IoFault... faults);
    public Boolean hasFaults();
    public A addNewFault(Integer errno,Integer weight);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> addNewFault();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> addNewFaultLike(IoFault item);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> setNewFaultLike(int index,IoFault item);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> editFault(int index);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> editFirstFault();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> editLastFault();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<A> editMatchingFault(Predicate<IoFaultBuilder> predicate);
    public Long getGid();
    public A withGid(Long gid);
    public Boolean hasGid();
    public A withNewGid(long arg1);
    public Long getIno();
    public A withIno(Long ino);
    public Boolean hasIno();
    public A withNewIno(long arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public String getLatency();
    public A withLatency(String latency);
    public Boolean hasLatency();
    public A withNewLatency(StringBuilder arg1);
    public A withNewLatency(int[] arg1,int arg2,int arg3);
    public A withNewLatency(char[] arg1);
    public A withNewLatency(StringBuffer arg1);
    public A withNewLatency(byte[] arg1,int arg2);
    public A withNewLatency(byte[] arg1);
    public A withNewLatency(char[] arg1,int arg2,int arg3);
    public A withNewLatency(byte[] arg1,int arg2,int arg3);
    public A withNewLatency(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewLatency(String arg1);
    public A addToMethods(int index,String item);
    public A setToMethods(int index,String item);
    public A addToMethods(String... items);
    public A addAllToMethods(Collection<String> items);
    public A removeFromMethods(String... items);
    public A removeAllFromMethods(Collection<String> items);
    public List<String> getMethods();
    public String getMethod(int index);
    public String getFirstMethod();
    public String getLastMethod();
    public String getMatchingMethod(Predicate<String> predicate);
    public Boolean hasMatchingMethod(Predicate<String> predicate);
    public A withMethods(List<String> methods);
    public A withMethods(String... methods);
    public Boolean hasMethods();
    public A addNewMethod(StringBuilder arg1);
    public A addNewMethod(int[] arg1,int arg2,int arg3);
    public A addNewMethod(char[] arg1);
    public A addNewMethod(StringBuffer arg1);
    public A addNewMethod(byte[] arg1,int arg2);
    public A addNewMethod(byte[] arg1);
    public A addNewMethod(char[] arg1,int arg2,int arg3);
    public A addNewMethod(byte[] arg1,int arg2,int arg3);
    public A addNewMethod(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewMethod(String arg1);
    
/**
 * This method has been deprecated, please use method buildMtime instead.
 * @return The buildable object.
 */
@Deprecated public Timespec getMtime();
    public Timespec buildMtime();
    public A withMtime(Timespec mtime);
    public Boolean hasMtime();
    public A withNewMtime(Long nsec,Long sec);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MtimeNested<A> withNewMtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MtimeNested<A> withNewMtimeLike(Timespec item);
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MtimeNested<A> editMtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MtimeNested<A> editOrNewMtime();
    public io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MtimeNested<A> editOrNewMtimeLike(Timespec item);
    public Long getNlink();
    public A withNlink(Long nlink);
    public Boolean hasNlink();
    public A withNewNlink(long arg1);
    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(int[] arg1,int arg2,int arg3);
    public A withNewPath(char[] arg1);
    public A withNewPath(StringBuffer arg1);
    public A withNewPath(byte[] arg1,int arg2);
    public A withNewPath(byte[] arg1);
    public A withNewPath(char[] arg1,int arg2,int arg3);
    public A withNewPath(byte[] arg1,int arg2,int arg3);
    public A withNewPath(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPath(String arg1);
    public Integer getPercent();
    public A withPercent(Integer percent);
    public Boolean hasPercent();
    public A withNewPercent(int arg0);
    public Integer getPerm();
    public A withPerm(Integer perm);
    public Boolean hasPerm();
    public A withNewPerm(int arg0);
    public Long getRdev();
    public A withRdev(Long rdev);
    public Boolean hasRdev();
    public A withNewRdev(long arg1);
    public Long getSize();
    public A withSize(Long size);
    public Boolean hasSize();
    public A withNewSize(long arg1);
    public String getSource();
    public A withSource(String source);
    public Boolean hasSource();
    public A withNewSource(StringBuilder arg1);
    public A withNewSource(int[] arg1,int arg2,int arg3);
    public A withNewSource(char[] arg1);
    public A withNewSource(StringBuffer arg1);
    public A withNewSource(byte[] arg1,int arg2);
    public A withNewSource(byte[] arg1);
    public A withNewSource(char[] arg1,int arg2,int arg3);
    public A withNewSource(byte[] arg1,int arg2,int arg3);
    public A withNewSource(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSource(String arg1);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(StringBuilder arg1);
    public A withNewType(int[] arg1,int arg2,int arg3);
    public A withNewType(char[] arg1);
    public A withNewType(StringBuffer arg1);
    public A withNewType(byte[] arg1,int arg2);
    public A withNewType(byte[] arg1);
    public A withNewType(char[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewType(String arg1);
    public Long getUid();
    public A withUid(Long uid);
    public Boolean hasUid();
    public A withNewUid(long arg1);
    public interface AtimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TimespecFluent<io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.AtimeNested<N>> {

            public N and();
            public N endAtime();    }


    public interface CtimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TimespecFluent<io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.CtimeNested<N>> {

            public N and();
            public N endCtime();    }


    public interface FaultsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IoFaultFluent<io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.FaultsNested<N>> {

            public N and();
            public N endFault();    }


    public interface MtimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TimespecFluent<io.fabric8.chaosmesh.v1alpha1.IoChaosActionFluent.MtimeNested<N>> {

            public N and();
            public N endMtime();    }


}
